/// <reference types="node" />
import { EventEmitter } from "events";
import BluebirdPromise from "bluebird-lst";
export interface ZipOptions {
    autoClose?: boolean;
    decodeStrings?: boolean;
    validateEntrySizes?: boolean;
}
export declare function openZip(file: string, options?: ZipOptions): Promise<ZipFile>;
export declare class ZipFile extends EventEmitter {
    private readonly fd;
    readonly fileSize: number;
    readonly entryCount: number;
    readonly decodeStrings: boolean;
    readonly validateEntrySizes: boolean;
    private readEntryCursor;
    private isOpen;
    constructor(fd: number, centralDirectoryOffset: number, fileSize: number, entryCount: number, comment: any, decodeStrings: boolean, validateEntrySizes: boolean);
    readEntries(): BluebirdPromise<Entry[]>;
    close(): Promise<void>;
    private readEntry();
    getDataPosition(entry: Entry): Promise<{
        start: number;
        end: number;
    }>;
}
export declare class Entry {
    compressionMethod: number;
    generalPurposeBitFlag: number;
    lastModFileDate: number;
    lastModFileTime: number;
    versionMadeBy: number;
    versionNeededToExtract: number;
    crc32: number;
    fileName: string | Buffer;
    fileComment: string | Buffer;
    comment: string | Buffer;
    compressedSize: number;
    uncompressedSize: number;
    fileNameLength: number;
    extraFieldLength: number;
    fileCommentLength: number;
    internalFileAttributes: number;
    externalFileAttributes: number;
    relativeOffsetOfLocalHeader: number;
    extraFields: Array<any>;
    isEncrypted(): boolean;
    isCompressed(): boolean;
}
